<?php

namespace Drupal\Tests\docx_to_html\FunctionalJavascript;

/**
 * Tests the DOCX to HTML conversion functionality.
 *
 * @group docx_to_html
 */
class DocxToHtmlTest extends DocxToHtmlTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['docx_to_html'];

  /**
   * The theme to use during testing.
   *
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests the DOCX to HTML conversion.
   */
  public function testDocxToHtmlConversion() {
    // Set up a user with permissions to access the custom page.
    $user = $this->drupalCreateUser(['access docx to html converter']);
    $this->drupalLogin($user);

    // Visit the DOCX to HTML conversion page.
    $this->drupalGet('/docx-to-html');

    // Check that the file input and convert button are present.
    $this->assertSession()->fieldExists('document');
    $this->assertSession()->elementExists('css', '#copy-button');

    // Chose the test Docx file.
    $this->uploadFileAndWaitForConversion('/docx_to_html_test.docx');

    // Verify the output content.
    $output = $this->getSession()->getPage()->find('css', '#output')->getHtml();
    $this->assertNotEmpty($output, 'The output HTML should not be empty after conversion.');

    // Verify that the "Copy the HTML" button is now visible.
    $this->assertSession()->elementAttributeNotContains('css', '#copy-button', 'style', 'display: none;');

    // Click the "Copy the HTML" button and verify the clipboard content.
    $this->getSession()->getPage()->find('css', '#copy-button')->click();
    $this->getSession()->getDriver()->getWebDriverSession()->accept_alert();
  }

  /**
   * Tests access to the DOCX to HTML conversion page for anonymous users.
   */
  public function testAccessAsAnonymous() {
    // Logout to ensure we are anonymous.
    $this->drupalLogout();

    // Attempt to visit the DOCX to HTML conversion page.
    $this->drupalGet('/docx-to-html');

    // Verify that the access is denied
    // by checking for the access denied message.
    $this->assertSession()->pageTextContains('You are not authorized to access this page.');
  }

}
